@@ -23,7 +23,7 @@ import json
 import os
 import sys
 
-from .models import load_model, quantize, dump_config
+from .models import load_model, quantize, dump_config, save_weights, load_weights
 from .models.transforms import fold_rescaling
 
 
@@ -88,6 +88,39 @@ def dump_model_config(model_path, skip_default=False, output_name=None):
     print(f"Saved quantization configuration to {output_name}.")
 
 
+def save_model_weights(model_path, weights_path):
+    """ CLI entry point to save the model weights in an npz file.
+
+    Args:
+        model_path (str): Path to the model to extract the weights from.
+        weights_path (str): Path to save the npz file.
+            Defaults to <model_path>.npz.
+    """
+    # Build name for weights file
+    if weights_path is None:
+        model_name = os.path.splitext(model_path)[0]
+        weights_path = f"{model_name}.npz"
+
+    # Load the model and save its weights
+    model = load_model(model_path)
+    save_weights(model, weights_path)
+    print(f"Saved model weights to {weights_path}.")
+
+
+def load_model_weights(model_path, weights_path):
+    """ CLI entry point to apply weights to a model from an npz file.
+
+    Args:
+        model_path (str): Path to the model on which apply the weights.
+        weights_path (str): Path to load the npz file.
+    """
+    # Update the model weights with the npz file
+    model = load_model(model_path)
+    load_weights(model, weights_path)
+    model.save(model_path, include_optimizer=False)
+    print(f"Saved model with new weights to {model_path}.")
+
+
 def main():
     """ CLI entry point.
 
@@ -121,6 +154,20 @@ def main():
     c_parser.add_argument("-o", "--output_path", type=str, help="Store quantization configuration. "
                           "Defaults to <model>_quant_config.json")
 
+    # Save weights arguments
+    w_parser = sp.add_parser("save_weights", help="Store models weights in an npz.")
+    w_parser.add_argument("-m", "--model", type=str, required=True,
+                          help="Model to extract weights from.")
+    w_parser.add_argument("-w", "--weights_path", type=str,
+                          help="Npz file that contains the saved weights.")
+
+    # Load weights arguments
+    w_parser = sp.add_parser("load_weights", help="Apply weights to a model from an npz file.")
+    w_parser.add_argument("-m", "--model", type=str, required=True,
+                          help="Model to apply the weights.")
+    w_parser.add_argument("-w", "--weights_path", type=str, required=True,
+                          help="Npz file that contains the weights to apply.")
+
     args = parser.parse_args()
 
     if args.action == "version":
@@ -145,3 +192,13 @@ def main():
             skip_default=args.skip_default,
             output_name=args.output_path,
         )
+    elif args.action == "save_weights":
+        save_model_weights(
+            model_path=args.model,
+            weights_path=args.weights_path,
+        )
+    elif args.action == "load_weights":
+        load_model_weights(
+            model_path=args.model,
+            weights_path=args.weights_path,
+        )
