@@ -17,8 +17,7 @@
 import keras
 import tensorflow as tf
 
-
-from ..tensors import FixedPoint, MAX_BUFFER_BITWIDTH
+from ..tensors import FixedPoint, MAX_BUFFER_BITWIDTH, round_log2, pow2
 from .reshaping import QuantizedReshape, QuantizedPermute
 from .softmax2 import softmax2, QuantizedSoftmax2
 from .layers import deserialize_quant_object, Calibrable
@@ -107,7 +106,11 @@ class Attention(keras.layers.Layer):
                 f" by number of heads = {self.num_heads}"
             )
         self.dim = self.hidden_size // self.num_heads
-        self.scale_rep = 1 / tf.math.sqrt(tf.cast(self.dim, dtype=tf.float32))
+
+        # Attention replace score / scale by a shift.
+        # For that, we need to calculate the shift_scale
+        scale = tf.math.sqrt(tf.cast(self.dim, dtype=tf.float32))
+        self.scale_shift = round_log2(scale)
 
     def separate_heads(self, x):
         x = keras.layers.Reshape((-1, self.num_heads, self.dim))(x)
@@ -120,8 +123,8 @@ class Attention(keras.layers.Layer):
         value = self.separate_heads(inputs[2])
         # Dot product query and key for each head and pairs of tokens
         score = tf.matmul(query, key, transpose_b=True)
-        # Rescale the corresponding score
-        scaled_score = score * self.scale_rep
+        # Rescale the corresponding score, dividing it by 2**scale_shift
+        scaled_score = score * pow2(-self.scale_shift)
         # Apply the configurable softmax operation
         mask = self.softmax_op(scaled_score, axis=-1)
         # Combine each score with value to obtain new embeddings per tokens
@@ -160,18 +163,9 @@ class QuantizedAttention(Calibrable, Attention):
         self.softmax_op = QuantizedSoftmax2(
             quant_config=softmax_quant_conf, name="quantized_softmax")
         # Extract other quantization parameters
-        self.ss_scale_bitwidth = self.quant_config.get("ss_scale_bitwidth", 4)
         self.buffer_bitwidth = self.quant_config.get(
             "buffer_bitwidth", MAX_BUFFER_BITWIDTH) - 1
 
-    def build(self, input_shape):
-        super().build(input_shape)
-        # Quantize dim reciprocal constant.
-        # It is always smaller than 1, so all values will be fractional
-        value_bits = self.ss_scale_bitwidth
-        self.scale_rep = FixedPoint.quantize(
-            self.scale_rep, value_bits, value_bits)
-
     def separate_heads(self, x):
         x = QuantizedReshape((-1, self.num_heads, self.dim))(x)
         return QuantizedPermute((2, 1, 3))(x)
@@ -188,8 +182,8 @@ class QuantizedAttention(Calibrable, Attention):
         query = query.promote(self.buffer_bitwidth)
         # Dot product query and key for each head and pairs of tokens
         score = tf.matmul(query, key, transpose_b=True)
-        # Rescale the corresponding score
-        scaled_score = score * self.scale_rep
+        # Rescale the corresponding score, dividing it by 2**scale_shift
+        scaled_score = score >> self.scale_shift
         # Apply the configurable softmax operation
         mask = self.softmax_op(scaled_score)
         # Promote mask to make sure we don't overflow
