@@ -192,11 +192,14 @@ class QuantizedLayerNormalization(Calibrable, LayerMadNormalization):
         mad_inv = reciprocal_lut(
             mad, self.mad_rec_frac_bits, self.buffer_bitwidth)
 
-        # In FixedPoint arithmetic the value/frac bits of an operation result are controlled
-        # by the left term. In the multiplication below, we want to keep the higher
-        # frac_bits value, which is owned by "mad_inv" variable. Hence "mad_inv" should
-        # be the left term.
-        outputs = mad_inv * gamma * x_shifted
+        # Rescale inputs
+        x_rescaled = x_shifted * mad_inv
+
+        # Downscale to recover the initial fractional bits
+        x_rescaled, _ = x_rescaled.downscale(x_shifted.frac_bits, self.buffer_bitwidth)
+
+        # Multiply by gamma
+        outputs = x_rescaled * gamma
 
         # Before adding the bias, we need aligned results
         outputs, _ = outputs.align(beta)
