@@ -27,7 +27,7 @@ from ..layers import (QuantizedDense, QuantizedLayerNormalization, QuantizedAddP
                       QuantizedReshape, QuantizedAttention, QuantizedConv2D, QuantizedMaxPool2D,
                       QuantizedGlobalAveragePooling2D, QuantizedExtractToken, Dequantizer,
                       Quantizer, QuantizedSeparableConv2D, QuantizedFlatten, QuantizedReciprocal,
-                      FixedPointQuantizer, UniformQuantizer)
+                      FixedPointQuantizer, UniformQuantizer, QuantizedConv2DTranspose)
 
 # Mapper to match float layer with its quantized version
 CUSTOM_QLAYERS = {
@@ -38,7 +38,8 @@ CUSTOM_QLAYERS = {
     "Attention": QuantizedAttention, 'MaxPooling2D': QuantizedMaxPool2D,
     'GlobalAveragePooling2D': QuantizedGlobalAveragePooling2D,
     "ExtractToken": QuantizedExtractToken, "SeparableConv2D": QuantizedSeparableConv2D,
-    "Flatten": QuantizedFlatten, "Reciprocal": QuantizedReciprocal, "PaddedConv2D": QuantizedConv2D
+    "Flatten": QuantizedFlatten, "Reciprocal": QuantizedReciprocal, "PaddedConv2D": QuantizedConv2D,
+    "Conv2DTranspose": QuantizedConv2DTranspose
 }
 # List of Quantizer layer's that do not have a float layer representation
 NO_FLOAT_CUSTOM_QLAYERS = [Dequantizer, FixedPointQuantizer, UniformQuantizer]
@@ -68,7 +69,7 @@ def _handle_not_quantizable_layers(model):
                 continue
             elif isinstance(inbound.inbound_layers, list):
                 raise RuntimeError(f"'{layer.name}' is not quantizable and has multiple inbounds "
-                                    "which is not supported.")
+                                   "which is not supported.")
 
             # Check if the layer inbound will be quantized but is not a Dequantizer to prevent
             # adding an additional Dequantizer.
@@ -77,10 +78,10 @@ def _handle_not_quantizable_layers(model):
                 # Inbound will be quantized, add a Dequantizer after it and return the model
                 inbound_name = inbound.inbound_layers.name
                 model = insert_layer(model, inbound_name,
-                                        Dequantizer(name=f"{inbound_name}_float_output"))
+                                     Dequantizer(name=f"{inbound_name}_float_output"))
                 warnings.warn(f"'{layer.name}' of type {layer.__class__} is not supported to "
-                               "quantize, a Dequantizer is added before it and quantization will "
-                               "stop at this layer.")
+                              "quantize, a Dequantizer is added before it and quantization will "
+                              "stop at this layer.")
                 return model
     return model
 
@@ -262,7 +263,7 @@ def quantize(model, q_config, add_dequantizer=True):
 
     # Append Dequantizer at the end of the model to convert the output to float value
     if (add_dequantizer and not isinstance(new_model.layers[-1], Dequantizer)
-         and not quantization_stopped):
+            and not quantization_stopped):
         out = Dequantizer(name="float_output")(out)
     return Model(new_model.input, out)
 
@@ -292,7 +293,7 @@ def dump_config(model, skip_default=False):
                     Quantizer(**conf_value)
                     if scale_bits is not None:
                         conf_value["scale_bits"] = scale_bits
-                except:
+                except Exception:
                     _update_config(conf_value)
                     continue
 
