@@ -18,15 +18,18 @@
 Common utility methods used in quantization models.
 """
 
-import os
+from pathlib import Path
+import numpy as np
 import tensorflow_addons as tfa
 from keras.models import clone_model, load_model as kload_model, Model
+import warnings
 
 from quantizeml.layers.quantizers import Quantizer, Dequantizer
 
 from ..layers import Calibrable
 
-__all__ = ['load_model', 'deep_clone_model', 'set_calibrate', 'insert_layer']
+__all__ = ['load_model', 'deep_clone_model', 'set_calibrate', 'insert_layer', 'load_weights',
+           'save_weights']
 
 
 def load_model(model_path, custom_layers={}, compile_model=True):
@@ -46,25 +49,6 @@ def load_model(model_path, custom_layers={}, compile_model=True):
     return kload_model(model_path, custom_objects=custom_layers, compile=compile_model)
 
 
-def _deep_copy_variables(src_model, dst_model):
-    """ Copy variables from the source model to the destination model.
-
-    Args:
-        src_model (keras.Model): the source model
-        dst_model (keras.Model): the destination model
-    """
-    def _assign_variables(src_layer, dst_layer):
-        for dst_v in dst_layer.variables:
-            for src_v in src_layer.variables:
-                if dst_v.name == src_v.name:
-                    dst_v.assign(src_v)
-                    break
-
-    for layer in src_model.layers:
-        new_layer = dst_model.get_layer(layer.name)
-        _assign_variables(layer, new_layer)
-
-
 def deep_clone_model(model, *args, **kwargs):
     """Clone a model, assign variable to variable. Useful when a clone function is used,
     and new layers have not the same number of parameters as the original layer.
@@ -77,7 +61,8 @@ def deep_clone_model(model, *args, **kwargs):
         :class:`keras.models.Model`: the cloned model
     """
     new_model = clone_model(model, *args, **kwargs)
-    _deep_copy_variables(model, new_model)
+    variables_dict = {var.name: var for var in model.variables}
+    apply_weights_to_model(new_model, variables_dict, False)
     return new_model
 
 
@@ -170,5 +155,72 @@ def insert_layer(model, target_layer_name, new_layer):
             model_outputs.append(x)
 
     new_model = Model(inputs=clone_model.inputs, outputs=model_outputs)
-    _deep_copy_variables(model, new_model)
+    variables_dict = {var.name: var for var in model.variables}
+    apply_weights_to_model(new_model, variables_dict, False)
     return new_model
+
+
+def apply_weights_to_model(model, weights, verbose=True):
+    """Loads weights from a dictionary and apply it to a model.
+
+    Go through the dictionary of weights, find the corresponding variable in the
+    model and partially load its weights.
+
+    Args:
+        model (keras.Model): the model to update
+        weights (dict): the dictionary of weights
+        verbose (bool, optional): if True, throw warning messages if a dict item is not found in the
+            model. Defaults to True.
+    """
+    if len(weights) == 0:
+        raise ValueError("There is no weight to apply to the model.")
+
+    # Go through the dictionary of weights with each item
+    for key, value in weights.items():
+        value_applied = False
+        for dest_var in model.variables:
+            if key == dest_var.name:
+                # Apply the current item value
+                dest_var.assign(value)
+                value_applied = True
+                break
+        if not value_applied and verbose:
+            warnings.warn(f"Variable '{key}' not found in the model.")
+
+
+def load_weights(model, weights_path):
+    """Loads weights from a npz file and apply it to a model.
+
+    Go through the dictionary of weights of the npz file, find the corresponding variable in the
+    model and partially load its weights.
+
+    Args:
+        model (keras.Model): the model to update
+        weights_path (str): the path of the npz file to load
+    """
+    # Check the npz file validity
+    path = Path(weights_path)
+    if not path.is_file():
+        raise ValueError(f"File `{weights_path}` not found.")
+
+    # Open the npz file
+    weights_dict = np.load(weights_path)
+
+    # Apply the weights to the model
+    apply_weights_to_model(model, weights_dict)
+
+
+def save_weights(model, weights_path):
+    """Save model weights on an npz file.
+
+    Takes a model and save the weights of all its layers into an npz file.
+
+    Args:
+        model (keras.Model): the model to save its weights
+        weights_path (str): the path of the npz file to save
+    """
+    weights_dict = {}
+    for var in model.variables:
+        weights_dict[var.name] = var
+
+    np.savez(weights_path, **weights_dict)
